import { ISecurityGroup } from "aws-cdk-lib/aws-ec2";
import { Construct } from "constructs";
import { IRabbitMqBroker } from "./rabbitmq-broker";
import { IRabbitMqBrokerDeployment, RabbitMqBrokerDeploymentBase, RabbitMqBrokerDeploymentProps } from "./rabbitmq-broker-deployment";
export interface IRabbitMqBrokerInstance extends IRabbitMqBrokerDeployment, IRabbitMqBroker {
}
export interface RabbitMqBrokerInstanceProps extends RabbitMqBrokerDeploymentProps {
}
/**
 * A representation of a single-instance broker comprised of one broker in one Availability Zone behind a Network Load Balancer (NLB)
 *
 * Additional optimizations:
 * - When subnet selection returns more then 1 subnets. A first one is picked. Warning is annotated
 */
export declare class RabbitMqBrokerInstance extends RabbitMqBrokerDeploymentBase implements IRabbitMqBrokerInstance {
    /**
     * Reference an existing RabbitMQ Broker Instance, defined outside of the CDK code, by ARN.
     *
     * @param scope
     * @param logicalId the construct's logical ID
     * @param arn the ARN of the existing RabbitMQ Broker Instance that is imported
     * @param securityGroups (optional) pass security groups for working with network connections
     * @param urlSuffix (optional) pass urlSuffix for the broker endpoints
     * @returns a representation of the RabbitMQ Broker Instance
     */
    static fromRabbitMqBrokerInstanceArn(scope: Construct, logicalId: string, arn: string, securityGroups?: ISecurityGroup[], urlSuffix?: string): IRabbitMqBrokerInstance;
    /**
     * Reference an existing RabbitMQ Broker Instance, defined outside of the CDK code, by its name and id.
     *
     * @param scope
     * @param logicalId
     * @param name the name of the existing RabbitMQ Broker Instance to be imported
     * @param id the ID of the existing RabbitMQ Broker Instance to be imported
     * @param securityGroups (optional) pass security groups for working with network connections
     * @param urlSuffix (optional) pass urlSuffix for the broker endpoints
     * @returns a representation of the RabbitMQ Broker Instance
     */
    static fromRabbitMqBrokerInstanceNameAndId(scope: Construct, logicalId: string, name: string, id: string, securityGroups?: ISecurityGroup[], urlSuffix?: string): IRabbitMqBrokerInstance;
    constructor(scope: Construct, id: string, props: RabbitMqBrokerInstanceProps);
}
